Learn R Programming

simodels (version 0.2.0)

si_oa_wpz_d: Destination Data for Leeds

Description

This dataset contains the number of trips destined for each workplace zone (WPZ) in Leeds.

Arguments

Details

See wicid.ukdataservice.ac.uk for details on the data source and the file data-raw/si_oa_wpz.qmd in the package repo for details on how the example dataset was generated.

Examples

Run this code
head(si_oa_wpz_d)
sf:::plot.sf(si_oa_wpz_d["n_d"])

Run the code above in your browser using DataLab