This dataset contains the number of trips destined for each workplace zone (WPZ) in Leeds.
Arguments
Details
See wicid.ukdataservice.ac.uk for details on the data source
and the file data-raw/si_oa_wpz.qmd in the package repo for details on how the example dataset was generated.